@@ -1,4 +1,4 @@
--- $Horde: nag/scripts/upgrades/1.1_to_2.0.mysql.sql,v 1.6.2.2 2005/10/18 12:56:50 jan Exp $
+-- $Horde: nag/scripts/upgrades/1.1_to_2.0.mysql.sql,v 1.6.2.3 2007/12/20 14:23:38 jan Exp $
 --
 -- You can simply execute this file in your database.
 --
@@ -10,7 +10,7 @@ ALTER TABLE nag_tasks DROP COLUMN task_modified;
 
 ALTER TABLE nag_tasks CHANGE COLUMN task_category task_category VARCHAR(80);
 ALTER TABLE nag_tasks CHANGE COLUMN task_id task_id VARCHAR(32) NOT NULL;
-ALTER TABLE nag_tasks CHANGE COLUMN task_private task_private SMALLINT NOT NULL default 0;
+ALTER TABLE nag_tasks CHANGE COLUMN task_private task_private SMALLINT DEFAULT 0 NOT NULL;
 
 ALTER TABLE nag_tasks ADD COLUMN task_uid VARCHAR(255) NOT NULL;
 ALTER TABLE nag_tasks ADD COLUMN task_alarm INT NOT NULL;
